# -*- coding: utf-8 -*-

from sqlalchemy import event
from efa.lib.esferror import render_esf_errors
from euhu.programs.qe import validate
from efa.lib.validators import build_data_to_validate
from efa.model.participation import (
    Participation, ParticipationFactory,
    get_esfindicator_fields, get_values,
    listener_adapter, generate_determine_reportable_function_for_participation
)
from ringo.lib.helpers import HTML, literal
from qe.model.participant import derive_indicators, recipe, program


class QEParticipation(Participation):
    """QE specific Participation"""

    def validate(self):
        """Hook for using the validate function in efa."""
        esf_fields = get_esfindicator_fields(self)
        esf_values = get_values(self, esf_fields)
        return validate(build_data_to_validate(esf_values, self))

    @classmethod
    def get_item_factory(cls):
        return ParticipationFactory(QEParticipation)

    @property
    def esf_errors(self):
        oktext = HTML.tag("abbr", class_="text-success", title="auswertbar", style="border-bottom:none;text-decoration:none", c=u'✔')
        fehlertext = HTML.tag("abbr",
                              title="fehlerhaft",
                              class_="text-danger",
                              style="font-weight: bold;border-bottom:none;text-decoration:none",
                              c=u'✖')
        nichtauswertbartext = HTML.tag("abbr",
                                       title="nicht auswertbar",
                                       class_="text-warning",
                                       style="font-weight: bold;border-bottom:none;text-decoration:none",
                                       c=u'❇')
        out = render_esf_errors(self, QEParticipation,
                                OK=oktext,
                                NICHTAUSWERTBAR=nichtauswertbartext,
                                FEHLER=fehlertext,
                                )
        return literal("").join(out)


tn_update_listener = listener_adapter(generate_determine_reportable_function_for_participation(
        derive_indicators,
        recipe,
        validate,
        program))

event.listen(QEParticipation, 'before_update', tn_update_listener)



